@@ -12,10 +12,12 @@ from version import version_info
 def update_relation(l, pkg, kind, version):
     found = False
     for pr in l:
-        for e in pr:
-            if e["name"] == pkg and e["version"] and e["version"][0] == kind:
-                e["version"] = (kind, version)
-                found = True
+        if len(pr) != 1: # only update simple build deps
+            continue
+        e = pr[0]
+        if e["name"] == pkg and e["version"] and e["version"][0] == kind:
+            e["version"] = (kind, version)
+            found = True
     if not found:
         l.append([{"version": (kind, version), "name": pkg, "arch": None}])
 
@@ -26,7 +28,7 @@ source = Deb822(f)
 def update_deps(control, field):
     bdi = PkgRelation.parse_relations(control[field])
     update_relation(bdi, "bzr", ">=", "%d.%d~" % version_info[:2])
-    update_relation(bdi, "bzr", "<<", "%d.%d~" % (version_info[0], version_info[1]+1))
+    update_relation(bdi, "bzr", "<<", "%d.%d.0" % (version_info[0], version_info[1]+1))
     control[field] = PkgRelation.str(bdi)
 
 update_deps(source, "Build-Depends-Indep")
